@@ -1,3 +1,6 @@
 from arkologger._config import LoggerConfig
 from arkologger._handler import *
-from arkologger._logger import Logger
+from arkologger._logger import (
+    LogFilter,
+    Logger,
+)
